searchData={"items":[{"type":"module","title":"Ueberauth.Strategy.NuSSO","doc":"NuSSO Strategy for Überauth. Redirects the user to an NuSSO\nlogin page and verifies the auth token the NuSSO server returns\nafter a successful login.\nThe login flow looks like this:\n1. User is redirected to the NuSSO server's login page by\n  `Ueberauth.Strategy.NuSSO.handle_request!`\n2. User signs in to the NuSSO server.\n3. NuSSO server redirects back to the Elixir application, sending\n   an auth token as an HTTP Cookie header.\n4. This auth token is validated by this Überauth NuSSO strategy,\n   fetching the user's information at the same time.\n5. User can proceed to use the Elixir application.","ref":"Ueberauth.Strategy.NuSSO.html"},{"type":"function","title":"Ueberauth.Strategy.NuSSO.credentials/1","doc":"Callback implementation for  Ueberauth.Strategy.credentials/1 .","ref":"Ueberauth.Strategy.NuSSO.html#credentials/1"},{"type":"function","title":"Ueberauth.Strategy.NuSSO.default_options/0","doc":"Callback implementation for  Ueberauth.Strategy.default_options/0 .","ref":"Ueberauth.Strategy.NuSSO.html#default_options/0"},{"type":"function","title":"Ueberauth.Strategy.NuSSO.extra/1","doc":"Ueberauth extra information callback. Returns all attributes the NuSSO\nserver returned about the user that authenticated.","ref":"Ueberauth.Strategy.NuSSO.html#extra/1"},{"type":"function","title":"Ueberauth.Strategy.NuSSO.handle_callback!/1","doc":"Ueberauth after login callback with a valid NuSSO Cookie.","ref":"Ueberauth.Strategy.NuSSO.html#handle_callback!/1"},{"type":"function","title":"Ueberauth.Strategy.NuSSO.handle_cleanup!/1","doc":"Callback implementation for  Ueberauth.Strategy.handle_cleanup!/1 .","ref":"Ueberauth.Strategy.NuSSO.html#handle_cleanup!/1"},{"type":"function","title":"Ueberauth.Strategy.NuSSO.handle_request!/1","doc":"Ueberauth `request` handler. Redirects to the NuSSO server's login page.","ref":"Ueberauth.Strategy.NuSSO.html#handle_request!/1"},{"type":"function","title":"Ueberauth.Strategy.NuSSO.info/1","doc":"Ueberauth user information.","ref":"Ueberauth.Strategy.NuSSO.html#info/1"},{"type":"function","title":"Ueberauth.Strategy.NuSSO.uid/1","doc":"Ueberauth UID callback.","ref":"Ueberauth.Strategy.NuSSO.html#uid/1"},{"type":"module","title":"Ueberauth.Strategy.NuSSO.API","doc":"NuSSO server API implementation.","ref":"Ueberauth.Strategy.NuSSO.API.html"},{"type":"function","title":"Ueberauth.Strategy.NuSSO.API.force_https/1","doc":"","ref":"Ueberauth.Strategy.NuSSO.API.html#force_https/1"},{"type":"function","title":"Ueberauth.Strategy.NuSSO.API.login_url/1","doc":"Returns the URL to the NuSSO server's login page","ref":"Ueberauth.Strategy.NuSSO.API.html#login_url/1"},{"type":"function","title":"Ueberauth.Strategy.NuSSO.API.redeem_token/1","doc":"Redeem an NuSSO SSO Token for the user attributes","ref":"Ueberauth.Strategy.NuSSO.API.html#redeem_token/1"},{"type":"function","title":"Ueberauth.Strategy.NuSSO.API.sso_cookie/0","doc":"Retrieve the configured SSO cookie header name","ref":"Ueberauth.Strategy.NuSSO.API.html#sso_cookie/0"},{"type":"exception","title":"Ueberauth.NuSSO.Error","doc":"","ref":"Ueberauth.NuSSO.Error.html"},{"type":"extras","title":"Ueberauth Strategy for Northwestern University Agentless SSO","doc":"# Ueberauth Strategy for Northwestern University Agentless SSO\n\n[![Build](https://github.com/nulib/ueberauth_nusso/actions/workflows/build.yml/badge.svg)](https://github.com/nulib/ueberauth_nusso/actions/workflows/build.yml)\n[![Coverage](https://coveralls.io/repos/github/nulib/ueberauth_nusso/badge.svg?branch=main)](https://coveralls.io/github/nulib/ueberauth_nusso?branch=main)\n[![Hex.pm](https://img.shields.io/hexpm/v/ueberauth_nusso.svg)](https://hex.pm/packages/ueberauth_nusso)\n\nNorthwestern University Agentless SSO strategy for [Ueberauth](https://github.com/ueberauth/ueberauth)","ref":"readme.html"},{"type":"extras","title":"Installation - Ueberauth Strategy for Northwestern University Agentless SSO","doc":"1. Add `ueberauth` and `ueberauth_nusso` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ueberauth, \"~> 0.2\"},\n    {:ueberauth_nusso, \"~> 0.3\"},\n  ]\nend\n```\n\n  2. Ensure `ueberauth_nusso` is started before your application:\n\n```elixir\ndef application do\n  [applications: [:ueberauth_nusso]]\nend\n```\n\n  3. Configure the NuSSO integration in `config/config.exs`:\n\n```elixir\nconfig :ueberauth, Ueberauth,\n  providers: [nusso: {Ueberauth.Strategy.NuSSO, []}]\n\nconfig :ueberauth, Ueberauth.Strategy.NuSSO,\n  base_url: \"http://websso.example.com/\",\n  consumer_key: \"AGENTLESS_SSO_CONSUMER_KEY\",\n  include_attributes: true\n```\n\n  4. In `AuthController` use the NuSSO strategy in your `login/4` function:\n\n```elixir\ndef login(conn, _params, _current_user, _claims) do\n  conn\n  |> Ueberauth.Strategy.NuSSO.handle_request!\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Contributing - Ueberauth Strategy for Northwestern University Agentless SSO","doc":"Issues and Pull Requests are always welcome!","ref":"readme.html#contributing"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}